@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 
 import toml
-import re, itertools
+import re, itertools, inspect
 import pandas as pd
 from pathlib import Path
 from inform import plural
@@ -30,6 +30,8 @@ from .util import *
 def load(toml_path, data_loader=None, merge_cols=None,
         path_guess=None, path_required=False, extras=None, on_alert=None):
     """
+    Load a microplate layout from a TOML file.
+
     Parse the given TOML file and return a `pandas.DataFrame` with a row for 
     each well and a column for each experimental condition specified in that 
     file.  If the **data_loader** and **merge_cols** arguments are provided 
@@ -38,14 +40,16 @@ def load(toml_path, data_loader=None, merge_cols=None,
 
     :param str,pathlib.Path toml_path:
         The path to a file describing the layout of one or more plates.  See 
-        the :doc:`file_format` page for details about this file.
+        the :doc:`/file_format` page for details about this file.
 
     :param callable data_loader:
         Indicates that `load()` should attempt to load the actual data 
         associated with the plate layout, in addition to loading the layout 
         itself.  The argument should be a function that takes a `pathlib.Path` 
         to a data file, parses it, and returns a `pandas.DataFrame` containing 
-        the parsed data.  Note that specifying a data loader implies that 
+        the parsed data.  The function may also take an argument named 
+        "extras", in which case the **extras** return value (described below) 
+        will be provided.  Note that specifying a data loader implies that 
         **path_required** is True.
 
     :param bool,dict merge_cols:
@@ -101,10 +105,10 @@ def load(toml_path, data_loader=None, merge_cols=None,
        
     :param str path_guess:
         Where to look for a data file if none is specified in the given TOML 
-        file.  In other words, this is the default value for ``meta.path``.  
-        This path is interpreted relative to the TOML file itself (unless it's 
-        an absolute path) and is formatted with a `pathlib.Path` representing 
-        said TOML file.  In code, that would be: 
+        file.  In other words, this is the default value for `meta.path`.  This 
+        path is interpreted relative to the TOML file itself (unless it's an 
+        absolute path) and is formatted with a `pathlib.Path` representing said 
+        TOML file.  In code, that would be: 
         ``path_guess.format(Path(toml_path))``.  A typical value would be 
         something like ``'{0.stem}.csv'``.
 
@@ -200,12 +204,30 @@ def load(toml_path, data_loader=None, merge_cols=None,
             in the TOML file that wouldn't otherwise be parsed).
             """
             if len(extras) == 1:
-                args += extras.popitem()[1],
+                args += list(extras.values())[0],
             if len(extras) > 1:
                 args += extras,
 
             return args if len(args) != 1 else args[0]
 
+        def get_extras_kwarg():
+            """
+            Helper function to determine whether or not to pass any "extras" 
+            (i.e. key/value pairs in the TOML file requested by the caller) to 
+            the **data_loader** function.
+            """
+            if not extras:
+                return {}
+
+            sig = inspect.signature(data_loader)
+
+            if 'extras' not in sig.parameters:
+                return {}
+            if sig.parameters['extras'].kind != inspect.Parameter.POSITIONAL_OR_KEYWORD:
+                return {}
+
+            return {'extras': add_extras()}
+
         layout = table_from_config(config, paths)
         layout = pd.concat([layout, *concats], sort=False)
 
@@ -225,9 +247,9 @@ def load(toml_path, data_loader=None, merge_cols=None,
         data = pd.DataFrame()
 
         for path in layout['path'].unique():
-           df = data_loader(path)
-           df['path'] = path
-           data = data.append(df, sort=False)
+            df = data_loader(path, **get_extras_kwarg())
+            df['path'] = path
+            data = data.append(df, sort=False)
 
         ## Merge the layout and the data into a single data frame:
         if not merge_cols:
